'use client'

import React, { useState, useEffect, useRef } from 'react'
import { motion, useAnimation } from 'framer-motion'
import { Inter } from 'next/font/google'

const inter = Inter({ subsets: ['latin'] })

const BannerWithCounterSection: React.FC = () => {
  const [timeLeft, setTimeLeft] = useState({
    days: 76,
    hours: 2,
    minutes: 36,
    seconds: 10
  })

  const controls = useAnimation()
  const ref = useRef<HTMLDivElement>(null)
  const [inView, setInView] = useState(false)

  useEffect(() => {
    const observer = new IntersectionObserver(
      ([entry]) => {
        setInView(entry.isIntersecting)
      },
      {
        threshold: 0.1
      }
    )

    if (ref.current) {
      observer.observe(ref.current)
    }

    return () => {
      if (ref.current) {
        observer.unobserve(ref.current)
      }
    }
  }, [])

  useEffect(() => {
    if (inView) {
      controls.start('visible')
    }
  }, [controls, inView])

  useEffect(() => {
    const timer = setInterval(() => {
      setTimeLeft(prevTime => {
        if (prevTime.days === 0 && prevTime.hours === 0 && prevTime.minutes === 0 && prevTime.seconds === 0) {
          clearInterval(timer)
          return prevTime
        }

        let newSeconds = prevTime.seconds - 1
        let newMinutes = prevTime.minutes
        let newHours = prevTime.hours
        let newDays = prevTime.days

        if (newSeconds < 0) {
          newSeconds = 59
          newMinutes -= 1
        }
        if (newMinutes < 0) {
          newMinutes = 59
          newHours -= 1
        }
        if (newHours < 0) {
          newHours = 23
          newDays -= 1
        }

        return { days: newDays, hours: newHours, minutes: newMinutes, seconds: newSeconds }
      })
    }, 1000)

    return () => clearInterval(timer)
  }, [])

  const containerVariants = {
    hidden: { opacity: 0, y: 50 },
    visible: {
      opacity: 1,
      y: 0,
      transition: {
        duration: 0.5,
        staggerChildren: 0.2
      }
    }
  }

  const itemVariants = {
    hidden: { opacity: 0, y: 20 },
    visible: {
      opacity: 1,
      y: 0,
      transition: { duration: 0.5 }
    }
  }

  return (
    <motion.section
      ref={ref}
      className={`bwcs-section bg-gradient-to-br from-purple-500 to-purple-400 py-20 px-4 ${inter.className}`}
      variants={containerVariants}
      initial="hidden"
      animate={controls}
    >
      <div className="bwcs-container max-w-4xl mx-auto text-center">
        <motion.h1 className="bwcs-title text-6xl md:text-8xl font-extrabold text-pink-100 mb-6 leading-tight" variants={itemVariants}>
          HELLO! How Can I Help You?
        </motion.h1>
        <motion.p className="bwcs-subtitle text-lg md:text-xl text-white mb-10" variants={itemVariants}>
          Get started today with a website that converts visitors into customers
        </motion.p>
        <motion.div className="bwcs-buttons space-x-4 mb-12" variants={itemVariants}>
          <button className="bwcs-button bg-gray-800 text-white px-6 py-3 rounded-md hover:bg-gray-700 transition-colors">
            Get Started Now
          </button>
          <button className="bwcs-button bg-orange-500 text-white px-6 py-3 rounded-md hover:bg-orange-400 transition-colors">
            Special Offer
          </button>
        </motion.div>
        <motion.div variants={itemVariants}>
          <h2 className="bwcs-offer-title text-2xl font-bold text-yellow-300 mb-6">Limited Time Offer!</h2>
          <div className="bwcs-timer flex justify-center space-x-4">
            {Object.entries(timeLeft).map(([unit, value]) => (
              <div key={unit} className="bwcs-timer-item bg-gray-800 text-white p-4 rounded-md w-24">
                <div className="bwcs-timer-value text-3xl font-bold">{value}</div>
                <div className="bwcs-timer-unit text-sm">{unit.charAt(0).toUpperCase() + unit.slice(1)}</div>
              </div>
            ))}
          </div>
        </motion.div>
      </div>
    </motion.section>
  )
}

export default BannerWithCounterSection